@@ -11,12 +11,12 @@ from pytest import raises
 
 
 from sqlite_database import Column, Database, integer, text
-from sqlite_database.config import Config
 from sqlite_database.signature import op
 from sqlite_database.operators import eq
 from sqlite_database.errors import TableRemovedError
 from sqlite_database.csv import to_csv_string, to_csv_file
 from sqlite_database.utils import crunch
+from sqlite_database.functions import Function
 
 
 def parse(data):
@@ -29,6 +29,8 @@ config = SimpleNamespace()
 file = abspath(f"{__file__}/../reports.txt")
 pstdout = StringIO()
 
+count = Function("COUNT")
+
 GROUP_BASE = [{
     "id": 0,
     "name": "root"
@@ -80,6 +82,27 @@ USER_UNEW = [{
     "role": "test0",
 }]
 
+COUNT_DATA = [{
+    "item_id": 1,
+    "quantity": 50,
+    "name": "A"
+}, {
+    "item_id": 2,
+    "quantity": 50,
+    "name": "A"
+
+}, {
+    "item_id": 3,
+    "quantity": 50,
+    "name": "A"
+
+}, {
+    "item_id": 4,
+    "quantity": 50,
+    "name": "A"
+
+}]
+
 
 def setup_database(database: Database):
     """setup database"""
@@ -112,8 +135,18 @@ def setup_database_builder(database: Database):
     groups.insert_many(GROUP_BASE)
     users.insert_many(USER_BASE)
 
+def setup_database_fns(database: Database):
+    """Setup database used for functions"""
+    checkout = database.create_table("checkout", [
+        integer("item_id").primary(),
+        text("name"),
+        integer('quantity')
+    ])
+    checkout.insert_many(COUNT_DATA)
+
 database = Database(temp_dir / "test.db") # type: ignore
 setup_database_builder(database)
+setup_database_fns(database)
 users = database.table('users')
 groups = database.table('groups')
 
@@ -163,10 +196,10 @@ def test_003_select_only():
 
 def test_004_select_crunch():
     """Test 004 select with crunch"""
-    database = Database(":memory:", Config(crunch=True))
+    database = Database(":memory:")
     groups = database.table('groups')
     setup_database(database)
-    assert groups.select() == GROUP_BASE_CRUNCHED
+    assert groups.select(squash=True) == GROUP_BASE_CRUNCHED
 
 def test_01_insert():
     """test 01 insert"""
@@ -246,6 +279,15 @@ def test_09_export_directory():
     setup_database(database)
     assert to_csv_file(database, temp_dir / "MemDB") # type: ignore
 
+def test_10_0_function_count():
+    """Count(*) usage"""
+    database = Database(":memory:")
+    setup_database_fns(database)
+    counted = count("*")
+    data = database.table("checkout").select(only=counted)
+    print(data)
+    assert data == 4
+
 def test_99_save_report():
     """Save reports"""
     with open(file, "w", encoding="utf-8") as xfile:
